==> kpogre_1.6.2.orig.tar.gz: kpogre-1.6.2/kpogre/PropertyPages/kpgtypeattributeproppage.h <==
//
// C++ Interface: kpgtypeattributeproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGTYPEATTRIBUTEPROPPAGE_H
#define KPGTYPEATTRIBUTEPROPPAGE_H

#include "kpgtypeattributeproppagebase.h"

// application specific includes
#include "kpgabstractpropertypage.h"

// include files for libpgxx 
#include <pqxx/util> 

class KPGTypeAttribute;

/**
  * Type attribute property page
  *
  * @author Lumir Vanek <lvanek@users.sourceforge.net>
  */
class KPGTypeAttributePropPage : public KPGTypeAttributePropPageBase, public KPGAbstractPropertyPage
{
    Q_OBJECT
public:
    KPGTypeAttributePropPage(QWidget *parent, KPGTypeAttribute *);
    ~KPGTypeAttributePropPage();

	// Display properties of underlying database object
	virtual void displayProperties();
	
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
protected:

	KPGTypeAttribute * m_pTypeAttribute;
	
protected slots:
    
	virtual void slotTablePropDblClicked(int, int, int, const QPoint &);	
	            
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);    
	
signals:

	void sigSearchObject(const pqxx::oid);
	            
    // Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
};

#endif

==> kpogre_3.0.0.orig.tar.gz: kpogre-3.0.0/kpogre/PropertyPages/kpgtypeattributeproppage.h <==
//
// C++ Interface: kpgtypeattributeproppage
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGTYPEATTRIBUTEPROPPAGE_H
#define KPGTYPEATTRIBUTEPROPPAGE_H

#include "kpgtypeattributeproppagebase.h"

// application specific includes
#include "kpgabstractpropertypage.h"

// include files for libpgxx 
#include <pqxx/util> 

class KPGTypeAttribute;

/**
  * Type attribute property page
  *
  * @author Lumir Vanek <lvanek@users.sourceforge.net>
  */
class KPGTypeAttributePropPage : public KPGTypeAttributePropPageBase, public KPGAbstractPropertyPage
{
    Q_OBJECT
public:
    KPGTypeAttributePropPage(QWidget *parent, KPGTypeAttribute *);
    ~KPGTypeAttributePropPage();

	// Display properties of underlying database object
	virtual void displayProperties();
	
	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return m_pTableProperties; }
	
protected:

	KPGTypeAttribute * m_pTypeAttribute;
	
protected slots:
    
	virtual void slotTablePropDblClicked(int, int, int, const QPoint &);	
	            
	// Consumes request for context menu for property table
	virtual void slotTablePropContextMenuRequested(int, int, const QPoint &);    
	
signals:

	void sigSearchObject(pqxx::oid);
	            
    // Emit request for context menu for property table
	void sigTablePropContextMenuRequested(int, int, const QPoint &);
};

#endif
